

def milliseconds_allowed_strings():
    return ['ms', 'milliseconds', 'm']


def seconds_allowed_strings():
    return ['s', 'seconds', 'sec']


def hours_allowed_strings():
    return ['h', 'hours', 'hrs', 'hour']


def days_allowed_strings():
    return ['d', 'days', 'day']


def years_allowed_strings():
    return ['y', 'years', 'yrs', 'year']


def minutes_allowed_strings():
    return ['min', 'minute', 'minutes']
